@@ -13,8 +13,7 @@ This file is a part of LoadGuard Runner.
 import os
 from typing import Any
 
-from jinja2 import FileSystemLoader, Environment
-
+from jinja2 import FileSystemLoader, Environment, BaseLoader
 
 
 class TemplatesManager(object):
@@ -23,27 +22,32 @@ class TemplatesManager(object):
 
     """
 
-    def __init__(self, path: str):
+    def __init__(self, path: str = None):
         """
         Create a new instance of :class:`loadguard.templates.TemplatesManager`
         :param path: The path to lookup.
         :type path: str
         """
-        if not os.path.isdir(path):
-            raise AttributeError(f"Path is missing: {path}")
-        file_loader = FileSystemLoader(path)
-        self.env = Environment(loader=file_loader)
+        self.base_env, self.file_env = Environment(loader=BaseLoader), None
 
-    def render(self, template_file: str, ctx: Any = None):
+        if path:
+            file_loader = FileSystemLoader(path)
+            self.file_env = Environment(loader=file_loader)
+
+
+    def render(self, template_obj: str, ctx: Any = None):
         """
         Render a template using the provided context.
 
-        :param template_file: The template file.
-        :type template_file: str
+        :param template_obj: The template file.
+        :type template_obj: str
         :param ctx: The context.
         :type ctx: :class:`typing.Any`
         :return: The rendering.
         :rtype: str
         """
-        template = self.env.get_template(template_file)
+        if self.file_env is not None and os.path.exists(template_obj):
+            template = self.file_env.get_template(template_obj)
+        else:
+            template = self.base_env.from_string(template_obj)
         return template.render(ctx)
